@@ -710,7 +710,11 @@ class ValueWrapper(object):
             return {
                 "vid": node.get_id().cast(),
                 "tags": {
-                    tag_name: node.properties(tag_name) for tag_name in node.tags()
+                    tag_name: {
+                        k: v.cast_primitive()
+                        for k, v in node.properties(tag_name).items()
+                    }
+                    for tag_name in node.tags()
                 },
             }
 
@@ -720,7 +724,7 @@ class ValueWrapper(object):
                 "dst": edge.end_vertex_id().cast(),
                 "type": edge.edge_name(),
                 "rank": edge.ranking(),
-                "props": edge.properties(),
+                "props": {k: v.cast_primitive() for k, v in edge.properties().items()},
             }
 
         def _cast_primitive(raw_value):
@@ -745,7 +749,7 @@ class ValueWrapper(object):
                 return {k: _cast_primitive(v) for k, v in raw_value.as_map().items()}
             elif _type == Value.TVAL:
                 return raw_value.as_time().get_local_time_str()
-            elif _type == Value.DTVAL:
+            elif _type == Value.DVAL:
                 return raw_value.as_date().__repr__()
             elif _type == Value.DTVAL:
                 return raw_value.as_datetime().get_local_datetime_str()
